==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/AdCoding.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdCoding:
	"""AdCoding commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("adCoding", core, parent)

	def set(self, ad_coding: enums.NfcAppDataCod, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:ADCoding \n
		Determines if application is proprietary or CRC-B. \n
			:param ad_coding: PROP| CRCB
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(ad_coding, enums.NfcAppDataCod)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:ADCoding {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcAppDataCod:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:ADCoding \n
		Determines if application is proprietary or CRC-B. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: ad_coding: PROP| CRCB"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:ADCoding?')
		return Conversions.str_to_scalar_enum(response, enums.NfcAppDataCod)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/AdCoding.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdCoding:
	"""AdCoding commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("adCoding", core, parent)

	def set(self, ad_coding: enums.NfcAppDataCod, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:ADCoding \n
		Snippet: driver.source.bb.nfc.cblock.adCoding.set(ad_coding = enums.NfcAppDataCod.CRCB, channel = repcap.Channel.Default) \n
		Determines if application is proprietary or CRC-B. \n
			:param ad_coding: PROP| CRCB
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(ad_coding, enums.NfcAppDataCod)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:ADCoding {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcAppDataCod:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:ADCoding \n
		Snippet: value: enums.NfcAppDataCod = driver.source.bb.nfc.cblock.adCoding.get(channel = repcap.Channel.Default) \n
		Determines if application is proprietary or CRC-B. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: ad_coding: PROP| CRCB"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:ADCoding?')
		return Conversions.str_to_scalar_enum(response, enums.NfcAppDataCod)
